summaryrefslogtreecommitdiffstats
path: root/core/java/android/accounts
diff options
context:
space:
mode:
authorSimranjit Singh Kohli <simranjit@google.com>2015-04-28 11:11:12 -0700
committerSimranjit Singh Kohli <simranjit@google.com>2015-04-28 12:57:28 -0700
commit1663b44cfd5fe589183dae5db769c843870cb5db (patch)
tree270185c46b81e77dcb99b87e95c20bff39c51d0b /core/java/android/accounts
parent340b198ccbd1a05e67d586c345139617d4b84ce0 (diff)
downloadframeworks_base-1663b44cfd5fe589183dae5db769c843870cb5db.zip
frameworks_base-1663b44cfd5fe589183dae5db769c843870cb5db.tar.gz
frameworks_base-1663b44cfd5fe589183dae5db769c843870cb5db.tar.bz2
[Update API]:
Rename accountAuthenticated to notifyAccountAuthenticated and other changes. Bug: 20642769 Change-Id: I7e69d6a9492691429af0d7c2f405e01e265fcedd
Diffstat (limited to 'core/java/android/accounts')
-rw-r--r--core/java/android/accounts/AccountManager.java11
1 files changed, 5 insertions, 6 deletions
diff --git a/core/java/android/accounts/AccountManager.java b/core/java/android/accounts/AccountManager.java
index 480d171..ffa36d6 100644
--- a/core/java/android/accounts/AccountManager.java
+++ b/core/java/android/accounts/AccountManager.java
@@ -207,8 +207,7 @@ public class AccountManager {
* were authenticated successfully. Time is specified in milliseconds since
* epoch.
*/
- public static final String KEY_LAST_AUTHENTICATE_TIME_MILLIS_EPOCH =
- "lastAuthenticatedTimeMillisEpoch";
+ public static final String KEY_LAST_AUTHENTICATED_TIME = "lastAuthenticatedTime";
/**
* Authenticators using 'customTokens' option will also get the UID of the
@@ -671,8 +670,8 @@ public class AccountManager {
}
/**
- * Informs the system that the account has been authenticated recently. This
- * recency may be used by other applications to verify the account. This
+ * Notifies the system that the account has just been authenticated. This
+ * information may be used by other applications to verify the account. This
* should be called only when the user has entered correct credentials for
* the account.
* <p>
@@ -685,7 +684,7 @@ public class AccountManager {
*
* @param account The {@link Account} to be updated.
*/
- public boolean accountAuthenticated(Account account) {
+ public boolean notifyAccountAuthenticated(Account account) {
if (account == null)
throw new IllegalArgumentException("account is null");
try {
@@ -1587,7 +1586,7 @@ public class AccountManager {
* password prompt.
*
* <p>Also the returning Bundle may contain {@link
* #KEY_LAST_AUTHENTICATE_TIME_MILLIS_EPOCH} indicating the last time the
* credential was validated/created.
*
* If an error occurred,{@link AccountManagerFuture#getResult()} throws:
@@ -1587,7 +1586,7 @@ public class AccountManager {
*
* <p>Also the returning Bundle may contain {@link
- * #KEY_LAST_AUTHENTICATE_TIME_MILLIS_EPOCH} indicating the last time the
+ * #KEY_LAST_AUTHENTICATED_TIME} indicating the last time the
* credential was validated/created.
*